/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_3Q.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_3Q *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_3Q_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_3Q();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_3Q::Heavy_WSTD_3Q(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_PeghPNm9);
  numBytes += sLine_init(&sLine_2doNZCke);
  numBytes += sLine_init(&sLine_xRqmwWll);
  numBytes += sLine_init(&sLine_ieqIalai);
  numBytes += sLine_init(&sLine_nFXkP7Ue);
  numBytes += sBiquad_init(&sBiquad_s_HNNty9Wy);
  numBytes += sLine_init(&sLine_C4M6tz02);
  numBytes += sLine_init(&sLine_PgT1dBpS);
  numBytes += sLine_init(&sLine_Y8rGJKn8);
  numBytes += sLine_init(&sLine_7gWopub3);
  numBytes += sBiquad_init(&sBiquad_s_yXcQANKc);
  numBytes += sLine_init(&sLine_SwocPmzT);
  numBytes += sLine_init(&sLine_AIAaoswU);
  numBytes += sLine_init(&sLine_9VBwLyQR);
  numBytes += sLine_init(&sLine_JWiWmnVg);
  numBytes += sLine_init(&sLine_ETFOD3Wq);
  numBytes += sBiquad_init(&sBiquad_s_qAKFNc7j);
  numBytes += sLine_init(&sLine_MANLddvn);
  numBytes += sLine_init(&sLine_IGl6ktJf);
  numBytes += sLine_init(&sLine_YmXjGNJL);
  numBytes += sLine_init(&sLine_mdLvtYkU);
  numBytes += sLine_init(&sLine_DnbME8A3);
  numBytes += sBiquad_init(&sBiquad_s_BEyjqb2h);
  numBytes += sLine_init(&sLine_xIxCQV5q);
  numBytes += sLine_init(&sLine_aBzlyJbh);
  numBytes += sLine_init(&sLine_IxdFblDZ);
  numBytes += sLine_init(&sLine_fSpEUWsv);
  numBytes += sBiquad_init(&sBiquad_s_ttLGeXvK);
  numBytes += sLine_init(&sLine_PnPXI1Iz);
  numBytes += sLine_init(&sLine_zmVYcQFi);
  numBytes += sLine_init(&sLine_Z5vKuRl9);
  numBytes += sLine_init(&sLine_EwFTfdq0);
  numBytes += sLine_init(&sLine_8zHigGSR);
  numBytes += sBiquad_init(&sBiquad_s_w2CfDOjz);
  numBytes += cVar_init_f(&cVar_giIWFmgL, 0.0f);
  numBytes += cVar_init_f(&cVar_RRh9zyqk, 0.0f);
  numBytes += cVar_init_f(&cVar_IsceGvyl, 0.0f);
  numBytes += cVar_init_f(&cVar_AawpJVXF, 0.0f);
  numBytes += cSlice_init(&cSlice_nO1ZIoxi, 1, -1);
  numBytes += cVar_init_f(&cVar_VAdrEaNO, 1337.0f);
  numBytes += cVar_init_f(&cVar_Wv7OqfmF, 0.0f);
  numBytes += cIf_init(&cIf_VMVwrAMX, false);
  numBytes += cIf_init(&cIf_7TkAFwAt, false);
  numBytes += cBinop_init(&cBinop_spqqenQI, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ppyHG6hw, false);
  numBytes += cBinop_init(&cBinop_UfDLITmq, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_721M0VjR, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_8XlooXRO, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_tkJm7aQ4, 0.0f);
  numBytes += cIf_init(&cIf_dzdAfzY2, false);
  numBytes += cIf_init(&cIf_JRLxyoYw, false);
  numBytes += cBinop_init(&cBinop_4149WaJC, 0.0f); // __pow
  numBytes += cIf_init(&cIf_LbNfxRGC, false);
  numBytes += cBinop_init(&cBinop_VblRNh5A, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_S9GfQs6m, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_citxf1Ca, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_VPN2BeT1, 0.0f);
  numBytes += cIf_init(&cIf_40erWT1y, false);
  numBytes += cIf_init(&cIf_eCZgHQU5, false);
  numBytes += cBinop_init(&cBinop_RWNeb6LA, 0.0f); // __pow
  numBytes += cIf_init(&cIf_0JvHfnFf, false);
  numBytes += cBinop_init(&cBinop_opLFqdA6, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ZGWVc3ec, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_gSIE2FNx, -15.0f); // __eq
  numBytes += cIf_init(&cIf_OanwwP4F, false);
  numBytes += cSlice_init(&cSlice_dJH82b8f, 1, -1);
  numBytes += cVar_init_f(&cVar_SRyGtZcs, 0.0f);
  numBytes += cSlice_init(&cSlice_IlLkwq9C, 1, -1);
  numBytes += cVar_init_f(&cVar_gOhAUMZz, 0.0f);
  numBytes += cSlice_init(&cSlice_tsCfuGBO, 1, -1);
  numBytes += cVar_init_f(&cVar_jkD1GQEl, 0.0f);
  numBytes += cSlice_init(&cSlice_9DJSXtxT, 1, -1);
  numBytes += cVar_init_f(&cVar_vmyLGcEr, 0.313f);
  numBytes += cBinop_init(&cBinop_gEyDoF85, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ZTRYNupu, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_LMyw0lq8, 0.0f);
  numBytes += cVar_init_f(&cVar_ZqIYE94S, 1337.0f);
  numBytes += cVar_init_f(&cVar_eA6wEUsV, 0.3f);
  numBytes += cBinop_init(&cBinop_NHtN0jkn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_97fRMXE6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2h8rcuEg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZjKuHncY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qQKSPziH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vmy0YW7z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WK4Je8Ye, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_uBLsglZC, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_OcUsMmi7, 0.0f);
  numBytes += cVar_init_f(&cVar_dOn5a8J6, 1337.0f);
  numBytes += cVar_init_f(&cVar_WFQzZuEk, 0.313f);
  numBytes += cBinop_init(&cBinop_1eeQLp4F, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0JttZA2h, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KtYDHBUD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6Z37nImB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Mg0Hb8V5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gPGkRf44, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_sW1EUs80, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_uzh4AhGj, 0.0f);
  numBytes += cVar_init_f(&cVar_JJqUFPYO, 1037.0f);
  numBytes += cVar_init_f(&cVar_Mo0lYBfs, 0.4f);
  numBytes += cBinop_init(&cBinop_dMx9OxIL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BgUTWTWc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Cf0sEnap, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HwpfUPIX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cJNYKjHU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_x63yNP0i, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_SXZUlFkk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MdEdL7y1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_i9T2iULm, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_ypBsWTuI, 1, -1);
  numBytes += cVar_init_f(&cVar_YnIP2LWm, 1337.0f);
  numBytes += cVar_init_f(&cVar_Up884mjS, 0.0f);
  numBytes += cIf_init(&cIf_EHJB986g, false);
  numBytes += cIf_init(&cIf_oUwgIGDK, false);
  numBytes += cBinop_init(&cBinop_aUxhAipz, 0.0f); // __pow
  numBytes += cIf_init(&cIf_v2UUrBe1, false);
  numBytes += cBinop_init(&cBinop_mZPoeC2S, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_RlAJeS7i, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_B67YqGzD, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_KoTbFzlV, 0.0f);
  numBytes += cIf_init(&cIf_k0pUcOfk, false);
  numBytes += cIf_init(&cIf_y33l8U3w, false);
  numBytes += cBinop_init(&cBinop_IrEILzcP, 0.0f); // __pow
  numBytes += cIf_init(&cIf_nqDvjGfs, false);
  numBytes += cBinop_init(&cBinop_FAwvaVn0, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_NyYPgomk, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_yHHNVIZX, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Wg5i8dzE, 0.0f);
  numBytes += cIf_init(&cIf_ahsKN1fa, false);
  numBytes += cIf_init(&cIf_kfaLenMN, false);
  numBytes += cBinop_init(&cBinop_U4Dd2sDG, 0.0f); // __pow
  numBytes += cIf_init(&cIf_pvuuLoaP, false);
  numBytes += cBinop_init(&cBinop_7nQGOBYV, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_GcNOkGcV, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_6d6e9Hab, -15.0f); // __eq
  numBytes += cIf_init(&cIf_CE1nWhJK, false);
  numBytes += cSlice_init(&cSlice_o9iXMELK, 1, -1);
  numBytes += cVar_init_f(&cVar_7dFybeeb, 0.0f);
  numBytes += cSlice_init(&cSlice_TnnFSAcz, 1, -1);
  numBytes += cVar_init_f(&cVar_Ljo8GL02, 0.0f);
  numBytes += cSlice_init(&cSlice_0oILouLE, 1, -1);
  numBytes += cVar_init_f(&cVar_gXIKP15b, 0.0f);
  numBytes += cSlice_init(&cSlice_jHApjjZC, 1, -1);
  numBytes += cVar_init_f(&cVar_WVKr0QZI, 0.313f);
  numBytes += cBinop_init(&cBinop_CLAwzaQ4, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_LDyQlbDL, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_wWFKWfCi, 0.0f);
  numBytes += cVar_init_f(&cVar_uYHnH0fs, 1337.0f);
  numBytes += cVar_init_f(&cVar_InaOSZOq, 0.3f);
  numBytes += cBinop_init(&cBinop_zFtacFGb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uq9muzdB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gRTqgdmZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_n0WQJHG3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EUJ2FuLG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PQVVsi1q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NQu4KEYa, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_PmBLigJ7, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_MwehV92X, 0.0f);
  numBytes += cVar_init_f(&cVar_EqwFWWfK, 1337.0f);
  numBytes += cVar_init_f(&cVar_fXl1h2j1, 0.313f);
  numBytes += cBinop_init(&cBinop_b9XwoSsF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iz6GShxO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oPW5rFWG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_a4b2I5dl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6C4NddIe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RVZ30OKG, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_4Jbbyrer, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_8yTBXMhN, 0.0f);
  numBytes += cVar_init_f(&cVar_RFQ3Ap6y, 1037.0f);
  numBytes += cVar_init_f(&cVar_AUc3SZsa, 0.4f);
  numBytes += cBinop_init(&cBinop_a8vNxkci, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_j3tHNdO1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DWWkpEt8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dNspfGkb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jXTDMSht, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_58LmSMfz, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_5zGoMm0B, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Zqg6iZb1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qroftpd4, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_f7SzeksC, 5705.6f);
  numBytes += cVar_init_f(&cVar_LTpNpimk, 313.3f);
  numBytes += cBinop_init(&cBinop_cW5k7Scg, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_pM1f0DmK, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_l7ZrQlvN, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_3Q::~Heavy_WSTD_3Q() {
  // nothing to free
}

HvTable *Heavy_WSTD_3Q::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_3Q::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZwwGRqNl_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7NJdzS6S_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SUOksvIK_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JxBxeEUW_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wNIHRlDl_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LvAy0FWj_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_L2dsIcKu_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7BLQQTSx_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eC4qsdrT_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xx2Y391G_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ELcm4dim_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dURnZfVT_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R7KFL5Ci_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RKolgoHb_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KP3upQ7K_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EVlFne2g_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MVrhRJ3g_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AOab3epC_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1ipOzc0y_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sbXgysQy_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cnN4fW3M_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Qh79NHLp_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_10NvJMTG_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9PEsCMxF_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dSRveeOI_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GqksLZ9L_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vCmv573f_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_f9JyuM72_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HxbXdZAH_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KIMBkouA_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NOd0JNGm_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LRNKXw2t_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_usAU7BZQ_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_3Q::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_3Q::cVar_giIWFmgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ipMPO30E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_RRh9zyqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2ZCBp5ii_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_IsceGvyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LgOIGaVO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_AawpJVXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6Xd3iND0_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WmhPEMT2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3u07eYmB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qDeTIzmW_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_uf6HjO2Z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nO1ZIoxi, 0, m, &cSlice_nO1ZIoxi_sendMessage);
      break;
    }
    default: {
      cSwitchcase_36wJ8QnK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_nO1ZIoxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aZZG1amx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aZZG1amx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_VAdrEaNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aZZG1amx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_aZZG1amx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_L2dsIcKu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_Wv7OqfmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_AmO4nT2Z_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_VMVwrAMX, 0, m, &cIf_VMVwrAMX_sendMessage);
}

void Heavy_WSTD_3Q::cIf_VMVwrAMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Vy8IZ5RP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_7TkAFwAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Wb97CKZC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_b8gRr6xe_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_fFsE61iL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_spqqenQI, HV_BINOP_POW, 0, m, &cBinop_spqqenQI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_spqqenQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ppyHG6hw, 0, m, &cIf_ppyHG6hw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4GTynZHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_BKQEd8kf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_crDpeDSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7TkAFwAt, 0, m, &cIf_7TkAFwAt_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ceJVkbk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NbL9Gf9X_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NbL9Gf9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7TkAFwAt, 1, m, &cIf_7TkAFwAt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_b8gRr6xe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_4GTynZHP_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Wb97CKZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ppyHG6hw, 0, m, &cIf_ppyHG6hw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BKQEd8kf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_spqqenQI, HV_BINOP_POW, 1, m, &cBinop_spqqenQI_sendMessage);
  cMsg_fFsE61iL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_ppyHG6hw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_SXZUlFkk, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_AmO4nT2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VMVwrAMX, 1, m, &cIf_VMVwrAMX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Vy8IZ5RP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_721M0VjR, HV_BINOP_GREATER_THAN, 1, m, &cBinop_721M0VjR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8XlooXRO, HV_BINOP_EQ, 1, m, &cBinop_8XlooXRO_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_lpMzX8lp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UfDLITmq, HV_BINOP_ADD, 0, m, &cBinop_UfDLITmq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UfDLITmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ceJVkbk0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_crDpeDSr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_721M0VjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ppyHG6hw, 1, m, &cIf_ppyHG6hw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8XlooXRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jDBaVKEG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_jDBaVKEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_SXZUlFkk, m);
}

void Heavy_WSTD_3Q::cCast_z3agfSt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UfDLITmq, HV_BINOP_ADD, 1, m, &cBinop_UfDLITmq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_721M0VjR, HV_BINOP_GREATER_THAN, 0, m, &cBinop_721M0VjR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8XlooXRO, HV_BINOP_EQ, 0, m, &cBinop_8XlooXRO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8cwOwhc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Wv7OqfmF, 0, m, &cVar_Wv7OqfmF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ERVvAFvx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lpMzX8lp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_tkJm7aQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_zYcTgbiF_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_dzdAfzY2, 0, m, &cIf_dzdAfzY2_sendMessage);
}

void Heavy_WSTD_3Q::cIf_dzdAfzY2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_m2GAVDyX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_JRLxyoYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Xu5qYX72_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_P1T7jHjw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_7vGJlMRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4149WaJC, HV_BINOP_POW, 0, m, &cBinop_4149WaJC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4149WaJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LbNfxRGC, 0, m, &cIf_LbNfxRGC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SZl7vY13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_nspJH8JL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_NL03CHMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JRLxyoYw, 0, m, &cIf_JRLxyoYw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_DwvjvViH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1SQiGJaz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1SQiGJaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JRLxyoYw, 1, m, &cIf_JRLxyoYw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_P1T7jHjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_SZl7vY13_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Xu5qYX72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_LbNfxRGC, 0, m, &cIf_LbNfxRGC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nspJH8JL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4149WaJC, HV_BINOP_POW, 1, m, &cBinop_4149WaJC_sendMessage);
  cMsg_7vGJlMRT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_LbNfxRGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qXnucl2d_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0WJ2XiIG_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_3SfO4Ycd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_zYcTgbiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dzdAfzY2, 1, m, &cIf_dzdAfzY2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_m2GAVDyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S9GfQs6m, HV_BINOP_GREATER_THAN, 1, m, &cBinop_S9GfQs6m_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_citxf1Ca, HV_BINOP_EQ, 1, m, &cBinop_citxf1Ca_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_yt2IZ1Vx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VblRNh5A, HV_BINOP_ADD, 0, m, &cBinop_VblRNh5A_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VblRNh5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DwvjvViH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NL03CHMX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_S9GfQs6m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LbNfxRGC, 1, m, &cIf_LbNfxRGC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_citxf1Ca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_asHchW2D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_asHchW2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qXnucl2d_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0WJ2XiIG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_3SfO4Ycd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_unlgYBqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yt2IZ1Vx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_ZVLUHQMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VblRNh5A, HV_BINOP_ADD, 1, m, &cBinop_VblRNh5A_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_S9GfQs6m, HV_BINOP_GREATER_THAN, 0, m, &cBinop_S9GfQs6m_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_citxf1Ca, HV_BINOP_EQ, 0, m, &cBinop_citxf1Ca_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bizyXClf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tkJm7aQ4, 0, m, &cVar_tkJm7aQ4_sendMessage);
}

void Heavy_WSTD_3Q::cVar_VPN2BeT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_SFDdZeV0_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_40erWT1y, 0, m, &cIf_40erWT1y_sendMessage);
}

void Heavy_WSTD_3Q::cIf_40erWT1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5dYgEWMd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_eCZgHQU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_15Vl615Q_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_WAJiO9qb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_78OeDx5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RWNeb6LA, HV_BINOP_POW, 0, m, &cBinop_RWNeb6LA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RWNeb6LA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0JvHfnFf, 0, m, &cIf_0JvHfnFf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BSilAr9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Wtrqf2tR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_iwoz9IKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eCZgHQU5, 0, m, &cIf_eCZgHQU5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_B6I7jbOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_M09RrRJa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_M09RrRJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eCZgHQU5, 1, m, &cIf_eCZgHQU5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WAJiO9qb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_BSilAr9K_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_15Vl615Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_0JvHfnFf, 0, m, &cIf_0JvHfnFf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Wtrqf2tR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RWNeb6LA, HV_BINOP_POW, 1, m, &cBinop_RWNeb6LA_sendMessage);
  cMsg_78OeDx5L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_0JvHfnFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_i9T2iULm, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_SFDdZeV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_40erWT1y, 1, m, &cIf_40erWT1y_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5dYgEWMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZGWVc3ec, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ZGWVc3ec_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gSIE2FNx, HV_BINOP_EQ, 1, m, &cBinop_gSIE2FNx_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_0Mf1YN0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_opLFqdA6, HV_BINOP_ADD, 0, m, &cBinop_opLFqdA6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_opLFqdA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B6I7jbOW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iwoz9IKj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZGWVc3ec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0JvHfnFf, 1, m, &cIf_0JvHfnFf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gSIE2FNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yTzm3SDy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_yTzm3SDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_i9T2iULm, m);
}

void Heavy_WSTD_3Q::cCast_5v8DVAtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_opLFqdA6, HV_BINOP_ADD, 1, m, &cBinop_opLFqdA6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZGWVc3ec, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ZGWVc3ec_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gSIE2FNx, HV_BINOP_EQ, 0, m, &cBinop_gSIE2FNx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_u72JLnOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VPN2BeT1, 0, m, &cVar_VPN2BeT1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BezwSf48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0Mf1YN0n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_OanwwP4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_MdEdL7y1, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_CttCylVv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dJH82b8f, 0, m, &cSlice_dJH82b8f_sendMessage);
      break;
    }
    default: {
      cSwitchcase_iJ0KJGXb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_dJH82b8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_i6owlgcl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_i6owlgcl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_SRyGtZcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_i6owlgcl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_i6owlgcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wNIHRlDl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_iJ0KJGXb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IlLkwq9C, 0, m, &cSlice_IlLkwq9C_sendMessage);
      break;
    }
    default: {
      cSwitchcase_uf6HjO2Z_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_IlLkwq9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_27ldEpG1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_27ldEpG1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_gOhAUMZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_27ldEpG1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_27ldEpG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eC4qsdrT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_36wJ8QnK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tsCfuGBO, 0, m, &cSlice_tsCfuGBO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_YpmLeORT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_tsCfuGBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wKvx6FsJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wKvx6FsJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_jkD1GQEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wKvx6FsJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_wKvx6FsJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LvAy0FWj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_YpmLeORT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9DJSXtxT, 0, m, &cSlice_9DJSXtxT_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_9DJSXtxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zGCavlGh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zGCavlGh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_vmyLGcEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zGCavlGh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_zGCavlGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7BLQQTSx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_M1wHCaKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PeghPNm9, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_jn1UVbGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2doNZCke, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_I2poeqfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xRqmwWll, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_fpEG2oZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ieqIalai, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_BDnvqDPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nFXkP7Ue, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_L5TvINLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3eYhtfWt_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_3eYhtfWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gEyDoF85, HV_BINOP_DIVIDE, 1, m, &cBinop_gEyDoF85_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dm4yv29f_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_aCxpFi0M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_0ZLKPn6u_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_4bD5Gxtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_aCxpFi0M_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0ZLKPn6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gEyDoF85, HV_BINOP_DIVIDE, 0, m, &cBinop_gEyDoF85_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dm4yv29f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4bD5Gxtz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_gEyDoF85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZTRYNupu, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZTRYNupu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZTRYNupu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JlLie7Lb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UyrYJKmV_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_Kj4WXpzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mTLUG8lO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_gb8x4hpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_15nPxicE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_8felLsGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_r4FyAS0e_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_r4FyAS0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZTRYNupu, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZTRYNupu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vnTUDJKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_K98NQaHs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_K98NQaHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QMx6Pul9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_VskanyIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LMyw0lq8, 1, m, &cVar_LMyw0lq8_sendMessage);
}

void Heavy_WSTD_3Q::cVar_LMyw0lq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JjGrP7Dn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ssWHQyje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_97fRMXE6, HV_BINOP_MULTIPLY, 1, m, &cBinop_97fRMXE6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HpbzfrXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ssWHQyje_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5Kl0eHhx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_JQuHidlb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JQuHidlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2h8rcuEg, HV_BINOP_MULTIPLY, 1, m, &cBinop_2h8rcuEg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_offjoq6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZjKuHncY, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZjKuHncY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0akBFv4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_offjoq6s_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_z7STua5v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qQKSPziH, HV_BINOP_MULTIPLY, 1, m, &cBinop_qQKSPziH_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_SvAsE7Nx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_PbQGvi2J_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PbQGvi2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vmy0YW7z, HV_BINOP_MULTIPLY, 1, m, &cBinop_vmy0YW7z_sendMessage);
}

void Heavy_WSTD_3Q::cVar_ZqIYE94S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t4i1QKdf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_8felLsGo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5mgQm8nV_sendMessage);
}

void Heavy_WSTD_3Q::cVar_eA6wEUsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_vnTUDJKE_sendMessage);
}

void Heavy_WSTD_3Q::cCast_UyrYJKmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_gb8x4hpC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JlLie7Lb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Kj4WXpzT_sendMessage);
}

void Heavy_WSTD_3Q::cSend_mTLUG8lO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dURnZfVT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_15nPxicE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ELcm4dim_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_IRpBAlam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xx2Y391G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_QMx6Pul9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VMMzoHVK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VMMzoHVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NHtN0jkn, HV_BINOP_MULTIPLY, 1, m, &cBinop_NHtN0jkn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NHtN0jkn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zQ5TMnf0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zQ5TMnf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IRpBAlam_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_JjGrP7Dn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Hf1A9ljB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Hf1A9ljB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VBz5TJd0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kncjuieP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HDi9l4Iy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EdV6xLfR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IWdG5WE6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JT10AYC2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_97fRMXE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M1wHCaKQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_2h8rcuEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jn1UVbGt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ZjKuHncY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I2poeqfR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_qQKSPziH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fpEG2oZG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_vmy0YW7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BDnvqDPW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_0HqWn8au_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZqIYE94S, 0, m, &cVar_ZqIYE94S_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KysRFlyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eA6wEUsV, 1, m, &cVar_eA6wEUsV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_EdV6xLfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZjKuHncY, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZjKuHncY_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VBz5TJd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_JT10AYC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_97fRMXE6, HV_BINOP_MULTIPLY, 0, m, &cBinop_97fRMXE6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HDi9l4Iy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qQKSPziH, HV_BINOP_MULTIPLY, 0, m, &cBinop_qQKSPziH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_IWdG5WE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2h8rcuEg, HV_BINOP_MULTIPLY, 0, m, &cBinop_2h8rcuEg_sendMessage);
}

void Heavy_WSTD_3Q::cCast_kncjuieP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vmy0YW7z, HV_BINOP_MULTIPLY, 0, m, &cBinop_vmy0YW7z_sendMessage);
}

void Heavy_WSTD_3Q::cCast_t4i1QKdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eA6wEUsV, 0, m, &cVar_eA6wEUsV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5mgQm8nV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LMyw0lq8, 0, m, &cVar_LMyw0lq8_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_e9pg1kp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_C4M6tz02, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_SVNNOih4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PgT1dBpS, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_fsEeEbzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y8rGJKn8, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_hHWDFHJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7gWopub3, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_tiTiahYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JC2TbNyi_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_JC2TbNyi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WK4Je8Ye, HV_BINOP_DIVIDE, 1, m, &cBinop_WK4Je8Ye_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TXgPFLpn_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_EoZJt30o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Dbb4S6oY_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_naUHEofX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_EoZJt30o_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Dbb4S6oY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WK4Je8Ye, HV_BINOP_DIVIDE, 0, m, &cBinop_WK4Je8Ye_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TXgPFLpn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_naUHEofX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_WK4Je8Ye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uBLsglZC, HV_BINOP_MULTIPLY, 1, m, &cBinop_uBLsglZC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uBLsglZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eFFH6cTu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j5lrniBz_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_rTLDcYF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7UFNL5NI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_ytYNUDJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_osXmrkSk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_PzifslY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_eYmOynes_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eYmOynes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uBLsglZC, HV_BINOP_MULTIPLY, 0, m, &cBinop_uBLsglZC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VTAEQvdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_YdfqK5X9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YdfqK5X9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rxQwUucP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_GHFJE8Bk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KtYDHBUD, HV_BINOP_MULTIPLY, 1, m, &cBinop_KtYDHBUD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wbBbUSsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OcUsMmi7, 1, m, &cVar_OcUsMmi7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MMib9GaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Z37nImB, HV_BINOP_MULTIPLY, 1, m, &cBinop_6Z37nImB_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_sxNKnvUZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_T3AuiHCt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_T3AuiHCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mg0Hb8V5, HV_BINOP_MULTIPLY, 1, m, &cBinop_Mg0Hb8V5_sendMessage);
}

void Heavy_WSTD_3Q::cVar_OcUsMmi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mr2CYNc9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_dOn5a8J6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5LVMXXRn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_PzifslY4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HXp3lVDC_sendMessage);
}

void Heavy_WSTD_3Q::cVar_WFQzZuEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_VTAEQvdQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_eFFH6cTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_rTLDcYF2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_j5lrniBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_ytYNUDJP_sendMessage);
}

void Heavy_WSTD_3Q::cSend_7UFNL5NI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KP3upQ7K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_osXmrkSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RKolgoHb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_QktgoDtQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_R7KFL5Ci_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_rxQwUucP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SlRU4ySM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SlRU4ySM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1eeQLp4F, HV_BINOP_MULTIPLY, 1, m, &cBinop_1eeQLp4F_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1eeQLp4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PQmwgSyT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PQmwgSyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QktgoDtQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_mr2CYNc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_h2zZgaPx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_h2zZgaPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JSYVaqOP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hG5zv52J_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sRZWHRfw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_exuxJPWM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0JttZA2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e9pg1kp5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_KtYDHBUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SVNNOih4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_6Z37nImB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fsEeEbzP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Mg0Hb8V5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hHWDFHJ5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_jQi23Jdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WFQzZuEk, 1, m, &cVar_WFQzZuEk_sendMessage);
}

void Heavy_WSTD_3Q::cCast_nvlzTi41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dOn5a8J6, 0, m, &cVar_dOn5a8J6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HXp3lVDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OcUsMmi7, 0, m, &cVar_OcUsMmi7_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5LVMXXRn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WFQzZuEk, 0, m, &cVar_WFQzZuEk_sendMessage);
}

void Heavy_WSTD_3Q::cCast_hG5zv52J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Z37nImB, HV_BINOP_MULTIPLY, 0, m, &cBinop_6Z37nImB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JSYVaqOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mg0Hb8V5, HV_BINOP_MULTIPLY, 0, m, &cBinop_Mg0Hb8V5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_sRZWHRfw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KtYDHBUD, HV_BINOP_MULTIPLY, 0, m, &cBinop_KtYDHBUD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_exuxJPWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0JttZA2h, HV_BINOP_MULTIPLY, 0, m, &cBinop_0JttZA2h_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ftTcaLjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SwocPmzT, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_EjaFpuhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AIAaoswU, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_OACTMS7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9VBwLyQR, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_3n8ONJCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JWiWmnVg, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Yx5j8gRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ETFOD3Wq, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_D6Hk3hqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0nAH8VCR_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_0nAH8VCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gPGkRf44, HV_BINOP_DIVIDE, 1, m, &cBinop_gPGkRf44_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yFb80AJk_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_l9Iqnl7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_D9dlQDgs_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_HuPPz5qT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_l9Iqnl7C_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_D9dlQDgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gPGkRf44, HV_BINOP_DIVIDE, 0, m, &cBinop_gPGkRf44_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yFb80AJk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HuPPz5qT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_gPGkRf44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sW1EUs80, HV_BINOP_MULTIPLY, 1, m, &cBinop_sW1EUs80_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sW1EUs80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uGiVKO8z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SI9yw3X1_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_rhtdZllP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IKWgj4FJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_VPp3sJFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DnAVSbAA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_MGp3oT5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_jJMlBNWT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jJMlBNWT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sW1EUs80, HV_BINOP_MULTIPLY, 0, m, &cBinop_sW1EUs80_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TXc4cs3P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_BycihMqd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BycihMqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3xz1VtoF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_UgMHUA4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BgUTWTWc, HV_BINOP_MULTIPLY, 1, m, &cBinop_BgUTWTWc_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_GgoiLNkl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mNkDPGHs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mNkDPGHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_UgMHUA4e_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_cAEziszZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_SFhFr3al_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SFhFr3al_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Cf0sEnap, HV_BINOP_MULTIPLY, 1, m, &cBinop_Cf0sEnap_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DyDVhmYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HwpfUPIX, HV_BINOP_MULTIPLY, 1, m, &cBinop_HwpfUPIX_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_6uPXFibF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_EIa4BOus_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EIa4BOus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DyDVhmYU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ou7f3gha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uzh4AhGj, 1, m, &cVar_uzh4AhGj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EFPaBB9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cJNYKjHU, HV_BINOP_MULTIPLY, 1, m, &cBinop_cJNYKjHU_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_N3BIcf6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_TiEJghIK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TiEJghIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x63yNP0i, HV_BINOP_MULTIPLY, 1, m, &cBinop_x63yNP0i_sendMessage);
}

void Heavy_WSTD_3Q::cVar_uzh4AhGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aLmQ4fTg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_JJqUFPYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QXR0nJMN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_MGp3oT5b_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7lH3exb6_sendMessage);
}

void Heavy_WSTD_3Q::cVar_Mo0lYBfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_TXc4cs3P_sendMessage);
}

void Heavy_WSTD_3Q::cCast_SI9yw3X1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_VPp3sJFU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_uGiVKO8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_rhtdZllP_sendMessage);
}

void Heavy_WSTD_3Q::cSend_IKWgj4FJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AOab3epC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_DnAVSbAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MVrhRJ3g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_lJcoQJXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EVlFne2g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_3xz1VtoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SlNzk6fU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SlNzk6fU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dMx9OxIL, HV_BINOP_MULTIPLY, 1, m, &cBinop_dMx9OxIL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dMx9OxIL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CdNqFgdZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CdNqFgdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lJcoQJXe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_aLmQ4fTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_fEyOgj5l_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fEyOgj5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dJpzHAw3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lh3O9ZA3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_10SWVFLw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g8MAgm6q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7FvSVUmQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DnjndX9O_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BgUTWTWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ftTcaLjj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Cf0sEnap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EjaFpuhD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_HwpfUPIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OACTMS7L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_cJNYKjHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3n8ONJCT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_x63yNP0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yx5j8gRQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_UFYb7gZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Mo0lYBfs, 1, m, &cVar_Mo0lYBfs_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vQ5knwAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JJqUFPYO, 0, m, &cVar_JJqUFPYO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_g8MAgm6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HwpfUPIX, HV_BINOP_MULTIPLY, 0, m, &cBinop_HwpfUPIX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dJpzHAw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_DnjndX9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BgUTWTWc, HV_BINOP_MULTIPLY, 0, m, &cBinop_BgUTWTWc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_10SWVFLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cJNYKjHU, HV_BINOP_MULTIPLY, 0, m, &cBinop_cJNYKjHU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7FvSVUmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Cf0sEnap, HV_BINOP_MULTIPLY, 0, m, &cBinop_Cf0sEnap_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Lh3O9ZA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x63yNP0i, HV_BINOP_MULTIPLY, 0, m, &cBinop_x63yNP0i_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QXR0nJMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Mo0lYBfs, 0, m, &cVar_Mo0lYBfs_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7lH3exb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uzh4AhGj, 0, m, &cVar_uzh4AhGj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qXnucl2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OanwwP4F, 1, m, &cIf_OanwwP4F_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_rv4dkr6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_MdEdL7y1, m);
}

void Heavy_WSTD_3Q::cBinop_0WJ2XiIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rv4dkr6u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_3SfO4Ycd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OanwwP4F, 0, m, &cIf_OanwwP4F_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_EiwLuQzD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ypBsWTuI, 0, m, &cSlice_ypBsWTuI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7Vs1zEcs_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_ypBsWTuI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_efx1fD4g_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_efx1fD4g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_YnIP2LWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_efx1fD4g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_efx1fD4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cnN4fW3M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_Up884mjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_v2U46rJe_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_EHJB986g, 0, m, &cIf_EHJB986g_sendMessage);
}

void Heavy_WSTD_3Q::cIf_EHJB986g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_NKEIJFS6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_oUwgIGDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_y7NZNyD6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_t8yq23bC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_X7LGjv5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_aUxhAipz, HV_BINOP_POW, 0, m, &cBinop_aUxhAipz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aUxhAipz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_v2UUrBe1, 0, m, &cIf_v2UUrBe1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sTBVCWBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_dsP5uXmX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_AFEPMJv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oUwgIGDK, 0, m, &cIf_oUwgIGDK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PiXDfEPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bX2A9HEO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bX2A9HEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oUwgIGDK, 1, m, &cIf_oUwgIGDK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_t8yq23bC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_sTBVCWBz_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_y7NZNyD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_v2UUrBe1, 0, m, &cIf_v2UUrBe1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dsP5uXmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aUxhAipz, HV_BINOP_POW, 1, m, &cBinop_aUxhAipz_sendMessage);
  cMsg_X7LGjv5h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_v2UUrBe1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_5zGoMm0B, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_v2U46rJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EHJB986g, 1, m, &cIf_EHJB986g_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NKEIJFS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RlAJeS7i, HV_BINOP_GREATER_THAN, 1, m, &cBinop_RlAJeS7i_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_B67YqGzD, HV_BINOP_EQ, 1, m, &cBinop_B67YqGzD_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_l41N1czV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mZPoeC2S, HV_BINOP_ADD, 0, m, &cBinop_mZPoeC2S_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mZPoeC2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PiXDfEPx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AFEPMJv7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RlAJeS7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_v2UUrBe1, 1, m, &cIf_v2UUrBe1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_B67YqGzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dX48QVkT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_dX48QVkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_5zGoMm0B, m);
}

void Heavy_WSTD_3Q::cCast_x9xvdDSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l41N1czV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_Pn6UmOKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mZPoeC2S, HV_BINOP_ADD, 1, m, &cBinop_mZPoeC2S_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RlAJeS7i, HV_BINOP_GREATER_THAN, 0, m, &cBinop_RlAJeS7i_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_B67YqGzD, HV_BINOP_EQ, 0, m, &cBinop_B67YqGzD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qYHWOWqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Up884mjS, 0, m, &cVar_Up884mjS_sendMessage);
}

void Heavy_WSTD_3Q::cVar_KoTbFzlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4wuh2QJY_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_k0pUcOfk, 0, m, &cIf_k0pUcOfk_sendMessage);
}

void Heavy_WSTD_3Q::cIf_k0pUcOfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_hysIBtzQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_y33l8U3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_6jvv3VN3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_6a8PC8DD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_11jR5d7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IrEILzcP, HV_BINOP_POW, 0, m, &cBinop_IrEILzcP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IrEILzcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nqDvjGfs, 0, m, &cIf_nqDvjGfs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jEv8S5J7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_SHoY8gmp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2YoU9Ros_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1Rl5xxiC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ogWXO8td_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y33l8U3w, 0, m, &cIf_y33l8U3w_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1Rl5xxiC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y33l8U3w, 1, m, &cIf_y33l8U3w_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6a8PC8DD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_jEv8S5J7_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_6jvv3VN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_nqDvjGfs, 0, m, &cIf_nqDvjGfs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SHoY8gmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IrEILzcP, HV_BINOP_POW, 1, m, &cBinop_IrEILzcP_sendMessage);
  cMsg_11jR5d7c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_nqDvjGfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3t36he1G_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_I6rNjmV3_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_EjYYIbrl_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_4wuh2QJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_k0pUcOfk, 1, m, &cIf_k0pUcOfk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hysIBtzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NyYPgomk, HV_BINOP_GREATER_THAN, 1, m, &cBinop_NyYPgomk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yHHNVIZX, HV_BINOP_EQ, 1, m, &cBinop_yHHNVIZX_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_rCwT5LIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FAwvaVn0, HV_BINOP_ADD, 0, m, &cBinop_FAwvaVn0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FAwvaVn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2YoU9Ros_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ogWXO8td_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NyYPgomk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nqDvjGfs, 1, m, &cIf_nqDvjGfs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yHHNVIZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nktQJZRG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_nktQJZRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3t36he1G_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_I6rNjmV3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_EjYYIbrl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_l4pKQm3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KoTbFzlV, 0, m, &cVar_KoTbFzlV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_fwPsG20y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rCwT5LIx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_Hz9QRM87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FAwvaVn0, HV_BINOP_ADD, 1, m, &cBinop_FAwvaVn0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NyYPgomk, HV_BINOP_GREATER_THAN, 0, m, &cBinop_NyYPgomk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yHHNVIZX, HV_BINOP_EQ, 0, m, &cBinop_yHHNVIZX_sendMessage);
}

void Heavy_WSTD_3Q::cVar_Wg5i8dzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Oqyf7bUf_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ahsKN1fa, 0, m, &cIf_ahsKN1fa_sendMessage);
}

void Heavy_WSTD_3Q::cIf_ahsKN1fa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_QWPDaINb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_kfaLenMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_FZVWe3KN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_WFpPG7Vf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_hiPkI6eu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_U4Dd2sDG, HV_BINOP_POW, 0, m, &cBinop_U4Dd2sDG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_U4Dd2sDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pvuuLoaP, 0, m, &cIf_pvuuLoaP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_40Pco1Js_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_soRVJumY_sendMessage);
}

void Heavy_WSTD_3Q::cCast_DgUDKnpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kfaLenMN, 0, m, &cIf_kfaLenMN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_u04ik6GH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_iK9ioaom_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iK9ioaom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kfaLenMN, 1, m, &cIf_kfaLenMN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WFpPG7Vf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_40Pco1Js_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_FZVWe3KN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_pvuuLoaP, 0, m, &cIf_pvuuLoaP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_soRVJumY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U4Dd2sDG, HV_BINOP_POW, 1, m, &cBinop_U4Dd2sDG_sendMessage);
  cMsg_hiPkI6eu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_pvuuLoaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_qroftpd4, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_Oqyf7bUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ahsKN1fa, 1, m, &cIf_ahsKN1fa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QWPDaINb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GcNOkGcV, HV_BINOP_GREATER_THAN, 1, m, &cBinop_GcNOkGcV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6d6e9Hab, HV_BINOP_EQ, 1, m, &cBinop_6d6e9Hab_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_s0IZha6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7nQGOBYV, HV_BINOP_ADD, 0, m, &cBinop_7nQGOBYV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7nQGOBYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u04ik6GH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DgUDKnpu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GcNOkGcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pvuuLoaP, 1, m, &cIf_pvuuLoaP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6d6e9Hab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ey2D47ZU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_ey2D47ZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qroftpd4, m);
}

void Heavy_WSTD_3Q::cCast_mCFq2sfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7nQGOBYV, HV_BINOP_ADD, 1, m, &cBinop_7nQGOBYV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GcNOkGcV, HV_BINOP_GREATER_THAN, 0, m, &cBinop_GcNOkGcV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6d6e9Hab, HV_BINOP_EQ, 0, m, &cBinop_6d6e9Hab_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MYTLuXx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Wg5i8dzE, 0, m, &cVar_Wg5i8dzE_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XtZp6yVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s0IZha6N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_CE1nWhJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Zqg6iZb1, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_mrDdO5Kv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_o9iXMELK, 0, m, &cSlice_o9iXMELK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OQDi8NnO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_o9iXMELK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_bbzwez3i_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_bbzwez3i_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_7dFybeeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bbzwez3i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_bbzwez3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1ipOzc0y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_OQDi8NnO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TnnFSAcz, 0, m, &cSlice_TnnFSAcz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EiwLuQzD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_TnnFSAcz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JvDLsWlr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JvDLsWlr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_Ljo8GL02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JvDLsWlr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_JvDLsWlr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_10NvJMTG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_7Vs1zEcs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0oILouLE, 0, m, &cSlice_0oILouLE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3oGjsbRf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_0oILouLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hwXgSn8l_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hwXgSn8l_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_gXIKP15b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hwXgSn8l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_hwXgSn8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sbXgysQy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_3oGjsbRf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jHApjjZC, 0, m, &cSlice_jHApjjZC_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_jHApjjZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wAuaCK46_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wAuaCK46_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_WVKr0QZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wAuaCK46_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_wAuaCK46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Qh79NHLp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_YDVi8xAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MANLddvn, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_p1eXgYjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IGl6ktJf, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ZuvTfWTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YmXjGNJL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_qi3rVzlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mdLvtYkU, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_E4inqKCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DnbME8A3, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_nLkqzQT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RVjnbtLt_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_RVjnbtLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CLAwzaQ4, HV_BINOP_DIVIDE, 1, m, &cBinop_CLAwzaQ4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lzU8qhOw_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_UTBW09Fg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_WXCD1rSC_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Fb8SPVyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_UTBW09Fg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WXCD1rSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CLAwzaQ4, HV_BINOP_DIVIDE, 0, m, &cBinop_CLAwzaQ4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lzU8qhOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fb8SPVyY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_CLAwzaQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LDyQlbDL, HV_BINOP_MULTIPLY, 1, m, &cBinop_LDyQlbDL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LDyQlbDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QpKDsPcO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FFdHtyol_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_fiSkchcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_A5K7L7Zw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_b5zW6Ig9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EwBfJGCL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_mI10MT9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_2S3oq80X_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2S3oq80X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LDyQlbDL, HV_BINOP_MULTIPLY, 0, m, &cBinop_LDyQlbDL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UU5lWV8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_399iyQwd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_399iyQwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W2sMKVnd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_E38bGfX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wWFKWfCi, 1, m, &cVar_wWFKWfCi_sendMessage);
}

void Heavy_WSTD_3Q::cVar_wWFKWfCi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DTGcDHcl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_JHsTf6Vl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uq9muzdB, HV_BINOP_MULTIPLY, 1, m, &cBinop_uq9muzdB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2ga7yRva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JHsTf6Vl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dhYTNHKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_bN7DtgBv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bN7DtgBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gRTqgdmZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_gRTqgdmZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DJJmdpRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n0WQJHG3, HV_BINOP_MULTIPLY, 1, m, &cBinop_n0WQJHG3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vOvWFUOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DJJmdpRg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DfXki4hf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EUJ2FuLG, HV_BINOP_MULTIPLY, 1, m, &cBinop_EUJ2FuLG_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_7VGsHDXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_wjTYg5OF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wjTYg5OF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PQVVsi1q, HV_BINOP_MULTIPLY, 1, m, &cBinop_PQVVsi1q_sendMessage);
}

void Heavy_WSTD_3Q::cVar_uYHnH0fs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bVXjkY6V_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_mI10MT9U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WD9E5G7L_sendMessage);
}

void Heavy_WSTD_3Q::cVar_InaOSZOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_UU5lWV8W_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QpKDsPcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_fiSkchcE_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FFdHtyol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_b5zW6Ig9_sendMessage);
}

void Heavy_WSTD_3Q::cSend_A5K7L7Zw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GqksLZ9L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_EwBfJGCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dSRveeOI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_EaC4QUcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9PEsCMxF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_W2sMKVnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_cnwkb71O_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cnwkb71O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zFtacFGb, HV_BINOP_MULTIPLY, 1, m, &cBinop_zFtacFGb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zFtacFGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gB4vEBxf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gB4vEBxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EaC4QUcA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_DTGcDHcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_EIn819z7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EIn819z7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3QzaZUsa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_twrjORPr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_goRB38J5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g2obsp6v_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A5Zivop5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hmexuppP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uq9muzdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YDVi8xAU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_gRTqgdmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p1eXgYjT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_n0WQJHG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZuvTfWTg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_EUJ2FuLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qi3rVzlC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_PQVVsi1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E4inqKCG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_4VENxUo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uYHnH0fs, 0, m, &cVar_uYHnH0fs_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ErIdQ5Bg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_InaOSZOq, 1, m, &cVar_InaOSZOq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3QzaZUsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_hmexuppP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uq9muzdB, HV_BINOP_MULTIPLY, 0, m, &cBinop_uq9muzdB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_goRB38J5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EUJ2FuLG, HV_BINOP_MULTIPLY, 0, m, &cBinop_EUJ2FuLG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_A5Zivop5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gRTqgdmZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_gRTqgdmZ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_twrjORPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PQVVsi1q, HV_BINOP_MULTIPLY, 0, m, &cBinop_PQVVsi1q_sendMessage);
}

void Heavy_WSTD_3Q::cCast_g2obsp6v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n0WQJHG3, HV_BINOP_MULTIPLY, 0, m, &cBinop_n0WQJHG3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WD9E5G7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wWFKWfCi, 0, m, &cVar_wWFKWfCi_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bVXjkY6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_InaOSZOq, 0, m, &cVar_InaOSZOq_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_at68fMve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xIxCQV5q, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_fHbZdd0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aBzlyJbh, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_TGKwp2nt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IxdFblDZ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_DRBp2vcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fSpEUWsv, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_5Fg2nxqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FewLrlE1_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_FewLrlE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NQu4KEYa, HV_BINOP_DIVIDE, 1, m, &cBinop_NQu4KEYa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lS0Y4kpO_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_ZJh6ulJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_wCk7z73G_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_m8fcQHjf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ZJh6ulJT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wCk7z73G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NQu4KEYa, HV_BINOP_DIVIDE, 0, m, &cBinop_NQu4KEYa_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lS0Y4kpO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m8fcQHjf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_NQu4KEYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PmBLigJ7, HV_BINOP_MULTIPLY, 1, m, &cBinop_PmBLigJ7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PmBLigJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mAKTmMvJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PEuLcqVd_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_npYY756L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sGnDKyji_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_d5TlxBZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NTGmnskk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_GqAkzJs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_GD58vDVe_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GD58vDVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PmBLigJ7, HV_BINOP_MULTIPLY, 0, m, &cBinop_PmBLigJ7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PM46fnXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_nZGzA8ng_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nZGzA8ng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rSr33cHu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Sdh6usyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oPW5rFWG, HV_BINOP_MULTIPLY, 1, m, &cBinop_oPW5rFWG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iByqueAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MwehV92X, 1, m, &cVar_MwehV92X_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TbkYK4IQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a4b2I5dl, HV_BINOP_MULTIPLY, 1, m, &cBinop_a4b2I5dl_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_RmdvdQkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hfrY91zC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hfrY91zC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6C4NddIe, HV_BINOP_MULTIPLY, 1, m, &cBinop_6C4NddIe_sendMessage);
}

void Heavy_WSTD_3Q::cVar_MwehV92X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_otHhrg9D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_EqwFWWfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9peMJMEo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_GqAkzJs6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FauFr8JR_sendMessage);
}

void Heavy_WSTD_3Q::cVar_fXl1h2j1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_PM46fnXh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mAKTmMvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_npYY756L_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PEuLcqVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_d5TlxBZu_sendMessage);
}

void Heavy_WSTD_3Q::cSend_sGnDKyji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HxbXdZAH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_NTGmnskk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_f9JyuM72_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_p7rZ5HLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vCmv573f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_rSr33cHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_PgCAl24k_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PgCAl24k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b9XwoSsF, HV_BINOP_MULTIPLY, 1, m, &cBinop_b9XwoSsF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_b9XwoSsF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jxSXwlHA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jxSXwlHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_p7rZ5HLc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_otHhrg9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_LCKp7yfq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LCKp7yfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TrN2fZ6W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TzZoRu4D_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XWeKXmi4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3pxlAgiO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iz6GShxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_at68fMve_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_oPW5rFWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fHbZdd0G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_a4b2I5dl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TGKwp2nt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_6C4NddIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DRBp2vcv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_Jx6FhhdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fXl1h2j1, 1, m, &cVar_fXl1h2j1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ttClnjbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EqwFWWfK, 0, m, &cVar_EqwFWWfK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FauFr8JR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MwehV92X, 0, m, &cVar_MwehV92X_sendMessage);
}

void Heavy_WSTD_3Q::cCast_9peMJMEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fXl1h2j1, 0, m, &cVar_fXl1h2j1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XWeKXmi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oPW5rFWG, HV_BINOP_MULTIPLY, 0, m, &cBinop_oPW5rFWG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TzZoRu4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a4b2I5dl, HV_BINOP_MULTIPLY, 0, m, &cBinop_a4b2I5dl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3pxlAgiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iz6GShxO, HV_BINOP_MULTIPLY, 0, m, &cBinop_iz6GShxO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TrN2fZ6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6C4NddIe, HV_BINOP_MULTIPLY, 0, m, &cBinop_6C4NddIe_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_mTGmqx9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PnPXI1Iz, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_JNWuozSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zmVYcQFi, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_YyZ0gaqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Z5vKuRl9, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_UBUfoyIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EwFTfdq0, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_nPMIsmud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8zHigGSR, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_jgnwjAHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9KtIW7b8_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_9KtIW7b8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RVZ30OKG, HV_BINOP_DIVIDE, 1, m, &cBinop_RVZ30OKG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h3slgnyN_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_MC8j0B78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_91nky2Wb_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_hj6GHU1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_MC8j0B78_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_91nky2Wb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RVZ30OKG, HV_BINOP_DIVIDE, 0, m, &cBinop_RVZ30OKG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_h3slgnyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hj6GHU1P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_RVZ30OKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Jbbyrer, HV_BINOP_MULTIPLY, 1, m, &cBinop_4Jbbyrer_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4Jbbyrer_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PGzkPhjJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GPMUb6MK_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_qnxfI2PC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_smdOKUPW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_qT7KEJ7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9FspIspj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_u7LjO8d0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_saUWNghn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_saUWNghn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Jbbyrer, HV_BINOP_MULTIPLY, 0, m, &cBinop_4Jbbyrer_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JJW1uemt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_PgpTaOuw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PgpTaOuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UvCqLUnh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_QJXNJUWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j3tHNdO1, HV_BINOP_MULTIPLY, 1, m, &cBinop_j3tHNdO1_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_81P3xN8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_EZAXcufX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EZAXcufX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QJXNJUWJ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_p46EHk6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LcwPMRYY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LcwPMRYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DWWkpEt8, HV_BINOP_MULTIPLY, 1, m, &cBinop_DWWkpEt8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4sowCIW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dNspfGkb, HV_BINOP_MULTIPLY, 1, m, &cBinop_dNspfGkb_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_stJyUotz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_u63hIRNP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_u63hIRNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4sowCIW9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tvaPUmTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8yTBXMhN, 1, m, &cVar_8yTBXMhN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gZB0UWVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jXTDMSht, HV_BINOP_MULTIPLY, 1, m, &cBinop_jXTDMSht_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Y2LAniEb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_IvviI5kw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IvviI5kw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_58LmSMfz, HV_BINOP_MULTIPLY, 1, m, &cBinop_58LmSMfz_sendMessage);
}

void Heavy_WSTD_3Q::cVar_8yTBXMhN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jy9ccCCE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_RFQ3Ap6y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rLMlz029_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_u7LjO8d0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EYzbC8Vg_sendMessage);
}

void Heavy_WSTD_3Q::cVar_AUc3SZsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_JJW1uemt_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GPMUb6MK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_qT7KEJ7q_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PGzkPhjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_qnxfI2PC_sendMessage);
}

void Heavy_WSTD_3Q::cSend_smdOKUPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LRNKXw2t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_9FspIspj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NOd0JNGm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_eNWWMkES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KIMBkouA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_UvCqLUnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_n5JWxLSN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_n5JWxLSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a8vNxkci, HV_BINOP_MULTIPLY, 1, m, &cBinop_a8vNxkci_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_a8vNxkci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Nvc2hARl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Nvc2hARl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eNWWMkES_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_Jy9ccCCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bLU0TF87_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bLU0TF87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CmSyZPHC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u3JTezWy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V3d6CvsS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_thbGLkDR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EFfwFJik_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hGlV2rG3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_j3tHNdO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mTGmqx9W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_DWWkpEt8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JNWuozSu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_dNspfGkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YyZ0gaqK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_jXTDMSht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UBUfoyIq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_58LmSMfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nPMIsmud_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_8ZzfChI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AUc3SZsa, 1, m, &cVar_AUc3SZsa_sendMessage);
}

void Heavy_WSTD_3Q::cCast_806Qolen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RFQ3Ap6y, 0, m, &cVar_RFQ3Ap6y_sendMessage);
}

void Heavy_WSTD_3Q::cCast_thbGLkDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dNspfGkb, HV_BINOP_MULTIPLY, 0, m, &cBinop_dNspfGkb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_CmSyZPHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_hGlV2rG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j3tHNdO1, HV_BINOP_MULTIPLY, 0, m, &cBinop_j3tHNdO1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_V3d6CvsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jXTDMSht, HV_BINOP_MULTIPLY, 0, m, &cBinop_jXTDMSht_sendMessage);
}

void Heavy_WSTD_3Q::cCast_EFfwFJik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DWWkpEt8, HV_BINOP_MULTIPLY, 0, m, &cBinop_DWWkpEt8_sendMessage);
}

void Heavy_WSTD_3Q::cCast_u3JTezWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_58LmSMfz, HV_BINOP_MULTIPLY, 0, m, &cBinop_58LmSMfz_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rLMlz029_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AUc3SZsa, 0, m, &cVar_AUc3SZsa_sendMessage);
}

void Heavy_WSTD_3Q::cCast_EYzbC8Vg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8yTBXMhN, 0, m, &cVar_8yTBXMhN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3t36he1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CE1nWhJK, 1, m, &cIf_CE1nWhJK_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_B50E7sE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Zqg6iZb1, m);
}

void Heavy_WSTD_3Q::cBinop_I6rNjmV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B50E7sE4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_EjYYIbrl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CE1nWhJK, 0, m, &cIf_CE1nWhJK_sendMessage);
}

void Heavy_WSTD_3Q::cVar_f7SzeksC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pM1f0DmK, HV_BINOP_DIVIDE, 0, m, &cBinop_pM1f0DmK_sendMessage);
}

void Heavy_WSTD_3Q::cVar_LTpNpimk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cW5k7Scg, HV_BINOP_DIVIDE, 1, m, &cBinop_cW5k7Scg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pM1f0DmK, HV_BINOP_DIVIDE, 1, m, &cBinop_pM1f0DmK_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_Xx27whXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l7ZrQlvN, HV_BINOP_DIVIDE, 0, m, &cBinop_l7ZrQlvN_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_8JQY6Q4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l7ZrQlvN, HV_BINOP_DIVIDE, 1, m, &cBinop_l7ZrQlvN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qDeTIzmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cW5k7Scg, HV_BINOP_DIVIDE, 0, m, &cBinop_cW5k7Scg_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3u07eYmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f7SzeksC, 0, m, &cVar_f7SzeksC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WmhPEMT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LTpNpimk, 0, m, &cVar_LTpNpimk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cW5k7Scg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_Xx27whXg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pM1f0DmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_8JQY6Q4G_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_l7ZrQlvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_InjWuhne_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_t41hlyNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_9kcxBvHF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zfVSitZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_70kxL6UO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_InjWuhne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_zfVSitZi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_70kxL6UO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_t41hlyNU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9kcxBvHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6nC6FUbp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_ipMPO30E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CttCylVv_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mrDdO5Kv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_2ZCBp5ii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CttCylVv_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mrDdO5Kv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_LgOIGaVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CttCylVv_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mrDdO5Kv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_6Xd3iND0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CttCylVv_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mrDdO5Kv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_6nC6FUbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CttCylVv_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mrDdO5Kv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_EGMFrhXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_AawpJVXF, 0, m, &cVar_AawpJVXF_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_GOovsJ1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_giIWFmgL, 0, m, &cVar_giIWFmgL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RRh9zyqk, 0, m, &cVar_RRh9zyqk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IsceGvyl, 0, m, &cVar_IsceGvyl_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ZwwGRqNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_giIWFmgL, 0, m, &cVar_giIWFmgL_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_SUOksvIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RRh9zyqk, 0, m, &cVar_RRh9zyqk_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_7NJdzS6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IsceGvyl, 0, m, &cVar_IsceGvyl_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_L2dsIcKu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dOn5a8J6, 0, m, &cVar_dOn5a8J6_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_7BLQQTSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jQi23Jdt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nvlzTi41_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_wNIHRlDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8cwOwhc0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z3agfSt2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ERVvAFvx_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_LvAy0FWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u72JLnOW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5v8DVAtq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BezwSf48_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_eC4qsdrT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bizyXClf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZVLUHQMo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_unlgYBqm_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_usAU7BZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L5TvINLT_sendMessage(_c, 0, m);
  cMsg_tiTiahYW_sendMessage(_c, 0, m);
  cMsg_D6Hk3hqQ_sendMessage(_c, 0, m);
  cMsg_nLkqzQT1_sendMessage(_c, 0, m);
  cMsg_5Fg2nxqy_sendMessage(_c, 0, m);
  cMsg_jgnwjAHn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ZqIYE94S, 0, m, &cVar_ZqIYE94S_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dOn5a8J6, 0, m, &cVar_dOn5a8J6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JJqUFPYO, 0, m, &cVar_JJqUFPYO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uYHnH0fs, 0, m, &cVar_uYHnH0fs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EqwFWWfK, 0, m, &cVar_EqwFWWfK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RFQ3Ap6y, 0, m, &cVar_RFQ3Ap6y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VAdrEaNO, 0, m, &cVar_VAdrEaNO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Wv7OqfmF, 0, m, &cVar_Wv7OqfmF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tkJm7aQ4, 0, m, &cVar_tkJm7aQ4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VPN2BeT1, 0, m, &cVar_VPN2BeT1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SRyGtZcs, 0, m, &cVar_SRyGtZcs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gOhAUMZz, 0, m, &cVar_gOhAUMZz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jkD1GQEl, 0, m, &cVar_jkD1GQEl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vmyLGcEr, 0, m, &cVar_vmyLGcEr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YnIP2LWm, 0, m, &cVar_YnIP2LWm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Up884mjS, 0, m, &cVar_Up884mjS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KoTbFzlV, 0, m, &cVar_KoTbFzlV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Wg5i8dzE, 0, m, &cVar_Wg5i8dzE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7dFybeeb, 0, m, &cVar_7dFybeeb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ljo8GL02, 0, m, &cVar_Ljo8GL02_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gXIKP15b, 0, m, &cVar_gXIKP15b_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WVKr0QZI, 0, m, &cVar_WVKr0QZI_sendMessage);
  cMsg_GOovsJ1G_sendMessage(_c, 0, m);
  cMsg_EGMFrhXe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_dURnZfVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NHtN0jkn, HV_BINOP_MULTIPLY, 0, m, &cBinop_NHtN0jkn_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ELcm4dim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_HpbzfrXH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_5Kl0eHhx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0akBFv4X_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_z7STua5v_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_xx2Y391G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VskanyIU_sendMessage);
  cMsg_SvAsE7Nx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_KP3upQ7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1eeQLp4F, HV_BINOP_MULTIPLY, 0, m, &cBinop_1eeQLp4F_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_RKolgoHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_MMib9GaJ_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_R7KFL5Ci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0JttZA2h, HV_BINOP_MULTIPLY, 1, m, &cBinop_0JttZA2h_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GHFJE8Bk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wbBbUSsP_sendMessage);
  cMsg_sxNKnvUZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_AOab3epC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dMx9OxIL, HV_BINOP_MULTIPLY, 0, m, &cBinop_dMx9OxIL_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_MVrhRJ3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GgoiLNkl_sendMessage(_c, 0, m);
  cMsg_cAEziszZ_sendMessage(_c, 0, m);
  cMsg_6uPXFibF_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_EFPaBB9U_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_EVlFne2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ou7f3gha_sendMessage);
  cMsg_N3BIcf6P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_cnN4fW3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EqwFWWfK, 0, m, &cVar_EqwFWWfK_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Qh79NHLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Jx6FhhdI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ttClnjbA_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_1ipOzc0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qYHWOWqg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Pn6UmOKT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x9xvdDSt_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_sbXgysQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MYTLuXx8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mCFq2sfA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XtZp6yVT_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_10NvJMTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l4pKQm3z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hz9QRM87_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fwPsG20y_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_GqksLZ9L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zFtacFGb, HV_BINOP_MULTIPLY, 0, m, &cBinop_zFtacFGb_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_dSRveeOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_2ga7yRva_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_dhYTNHKV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_vOvWFUOP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_DfXki4hf_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_9PEsCMxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_E38bGfX9_sendMessage);
  cMsg_7VGsHDXw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_HxbXdZAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b9XwoSsF, HV_BINOP_MULTIPLY, 0, m, &cBinop_b9XwoSsF_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_f9JyuM72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_TbkYK4IQ_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_vCmv573f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iz6GShxO, HV_BINOP_MULTIPLY, 1, m, &cBinop_iz6GShxO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Sdh6usyA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_iByqueAw_sendMessage);
  cMsg_RmdvdQkM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_LRNKXw2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a8vNxkci, HV_BINOP_MULTIPLY, 0, m, &cBinop_a8vNxkci_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_NOd0JNGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_81P3xN8a_sendMessage(_c, 0, m);
  cMsg_p46EHk6S_sendMessage(_c, 0, m);
  cMsg_stJyUotz_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_gZB0UWVa_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_KIMBkouA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_tvaPUmTw_sendMessage);
  cMsg_Y2LAniEb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_JxBxeEUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AawpJVXF, 0, m, &cVar_AawpJVXF_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_3Q::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9;

  // input and output vars
  hv_bufferf_t O0, O1, O2, O3, O4, O5;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));
    __hv_zero_f(VOf(O2));
    __hv_zero_f(VOf(O3));
    __hv_zero_f(VOf(O4));
    __hv_zero_f(VOf(O5));

    // process all signal functions
    __hv_line_f(&sLine_PeghPNm9, VOf(Bf0));
    __hv_line_f(&sLine_2doNZCke, VOf(Bf1));
    __hv_line_f(&sLine_xRqmwWll, VOf(Bf2));
    __hv_line_f(&sLine_ieqIalai, VOf(Bf3));
    __hv_line_f(&sLine_nFXkP7Ue, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_HNNty9Wy, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_SXZUlFkk, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_C4M6tz02, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_PgT1dBpS, VOf(Bf1));
    __hv_line_f(&sLine_Y8rGJKn8, VOf(Bf0));
    __hv_line_f(&sLine_7gWopub3, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_yXcQANKc, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_MdEdL7y1, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_SwocPmzT, VOf(Bf5));
    __hv_line_f(&sLine_AIAaoswU, VOf(Bf1));
    __hv_line_f(&sLine_9VBwLyQR, VOf(Bf2));
    __hv_line_f(&sLine_JWiWmnVg, VOf(Bf4));
    __hv_line_f(&sLine_ETFOD3Wq, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_qAKFNc7j, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_i9T2iULm, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_MANLddvn, VOf(Bf6));
    __hv_line_f(&sLine_IGl6ktJf, VOf(Bf2));
    __hv_line_f(&sLine_YmXjGNJL, VOf(Bf1));
    __hv_line_f(&sLine_mdLvtYkU, VOf(Bf5));
    __hv_line_f(&sLine_DnbME8A3, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_BEyjqb2h, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_5zGoMm0B, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_xIxCQV5q, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_aBzlyJbh, VOf(Bf2));
    __hv_line_f(&sLine_IxdFblDZ, VOf(Bf6));
    __hv_line_f(&sLine_fSpEUWsv, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_ttLGeXvK, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_Zqg6iZb1, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_PnPXI1Iz, VOf(Bf8));
    __hv_line_f(&sLine_zmVYcQFi, VOf(Bf2));
    __hv_line_f(&sLine_Z5vKuRl9, VOf(Bf1));
    __hv_line_f(&sLine_EwFTfdq0, VOf(Bf7));
    __hv_line_f(&sLine_8zHigGSR, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_w2CfDOjz, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_qroftpd4, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf0), VIf(O2), VOf(O2));
    __hv_add_f(VIf(Bf7), VIf(O5), VOf(O5));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf6), VIf(O3), VOf(O3));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf4), VIf(O4), VOf(O4));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
    __hv_store_f(outputBuffers[2]+n, VIf(O2));
    __hv_store_f(outputBuffers[3]+n, VIf(O3));
    __hv_store_f(outputBuffers[4]+n, VIf(O4));
    __hv_store_f(outputBuffers[5]+n, VIf(O5));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_3Q::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 6 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(6*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);
  bOut[2] = outputBuffers+(2*n4);
  bOut[3] = outputBuffers+(3*n4);
  bOut[4] = outputBuffers+(4*n4);
  bOut[5] = outputBuffers+(5*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_3Q::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 6 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(6*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  
  // interleave the heavy output into the output buffer
  for (int i = 0; i < 6; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+6*j] = bOut[i*n4+j];
    }
  }

  return n;
}
